@@ -1,11 +1,12 @@
 CNV.analyze <-
-function(normal, tumor, logR=NULL, coverage.cutoff=15, normal.chr=c("chr1","chr2","chr3","chr4","chr5","chr6","chr7","chr8","chr9","chr10","chr11","chr12","chr13","chr14","chr15","chr16","chr17","chr18","chr19","chr20","chr21","chr22","chrX","chrY"), c=0.5, write.file=FALSE, file=NULL, 
+function(normal, tumor, logR=NULL, coverage.cutoff=15, normal.chrs=c("chr1","chr2","chr3","chr4","chr5","chr6","chr7","chr8","chr9","chr10","chr11","chr12","chr13","chr14","chr15","chr16","chr17","chr18","chr19","chr20","chr21","chr22","chrX","chrY"), normal.chr=normal.chrs, c=0.5, write.file=FALSE, file=NULL, 
 		       doDNAcopy=TRUE, sdundo=1, smooth=TRUE, alpha=0.01, plot.cnv=TRUE) {
 	`%+%` <- function(x,y) paste(x,y,sep="")
+	normal.chrs = intersect(levels(normal$chr), normal.chrs)
 
     # first, do it for exons with enough coverage
 	well.covered.exon.idx = (normal$average.coverage > coverage.cutoff) & (tumor$average.coverage > coverage.cutoff)
-	if (is.null(logR)) norm.log.ratio = calculate.logR(normal, tumor, normal.chr)
+	if (is.null(logR)) norm.log.ratio = calculate.logR(normal, tumor, normal.chrs)
 	else norm.log.ratio = logR
 
 	if (doDNAcopy) {
